import board
import busio
import time
import usb_hid
from adafruit_hid.keyboard import Keyboard
from adafruit_hid.keycode import Keycode
import adafruit_vcnl4040

# Initialize I2C bus using STEMMA QT port
i2c = busio.I2C(board.SCL1, board.SDA1)

# Initialize VCNL4040 sensor
vcnl4040 = adafruit_vcnl4040.VCNL4040(i2c)

# Initialize keyboard HID
keyboard = Keyboard(usb_hid.devices)

# Set the proximity threshold for significant movement
PROXIMITY_THRESHOLD = 10

# Store the previous proximity reading
last_proximity = vcnl4040.proximity

while True:
    try:
        # Read the current proximity value
        current_proximity = vcnl4040.proximity
        print(f"Current proximity: {current_proximity}")

        # Check if proximity has increased by more than the threshold (movement closer)
        if (current_proximity - last_proximity) >= PROXIMITY_THRESHOLD:
            # Simulate pressing the Space key (press and release)
            keyboard.press(Keycode.SPACE)
            print("Space key pressed!")
            time.sleep(0.1)  # Short delay to simulate a key press
            keyboard.release(Keycode.SPACE)
            print("SPACE key released!")

        # Update last_proximity after every reading to track changes more accurately
        last_proximity = current_proximity
        ## Shorten the delay slightly for better responsiveness
        time.sleep(0.25)
    except OSError as e:
        print("Sensor error:", e)